@@ -1,10 +1,12 @@
 /*
   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filterplaintest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "filterimportertest.h"
 #include <MailImporter/FilterPlain>
 #include <QTest>
@@ -41,7 +43,7 @@ void FilterPlainTest::canNotImportDataUnknowPath()
     auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
     filter.setFilterInfo(&info);
-    filter.importMails(QStringLiteral("/foo/kde/bla/toto/"));
+    filter.importMails(u"/foo/kde/bla/toto/"_s);
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
     delete importerTest;
 }
